@@ -8,19 +8,13 @@ from typing import Iterable
 
 from cleo.io.io import IO
 from poetry.core.packages.dependency_group import MAIN_GROUP
-
-
-try:
-    from poetry.repositories.http_repository import (  # type: ignore[import] # noqa: E501
-        HTTPRepository,
-    )
-except ImportError:  # poetry<1.3.0
-    from poetry.repositories.http import HTTPRepository
+from poetry.repositories.http_repository import HTTPRepository
 
 from poetry_plugin_export.walker import get_project_dependency_packages
 
 
 if TYPE_CHECKING:
+    from collections.abc import Collection
     from pathlib import Path
 
     from packaging.utils import NormalizedName
@@ -47,14 +41,14 @@ class Exporter:
         self._with_hashes = True
         self._with_credentials = False
         self._with_urls = True
-        self._extras: bool | list[NormalizedName] | None = []
+        self._extras: Collection[NormalizedName] = ()
         self._groups: Iterable[str] = [MAIN_GROUP]
 
     @classmethod
     def is_format_supported(cls, fmt: str) -> bool:
         return fmt in cls.EXPORT_METHODS
 
-    def with_extras(self, extras: bool | list[NormalizedName] | None) -> Exporter:
+    def with_extras(self, extras: Collection[NormalizedName]) -> Exporter:
         self._extras = extras
 
         return self
@@ -101,6 +95,7 @@ class Exporter:
         for dependency_package in get_project_dependency_packages(
             self._poetry.locker,
             project_requires=root.all_requires,
+            root_package_name=root.name,
             project_python_marker=root.python_marker,
             extras=self._extras,
         ):
